==> ozacc-mail-1.1-rc2-src.zip: ozacc-mail-1.1-rc2/src/java/com/ozacc/mail/impl/OMLMimeMessage.java <==
package com.ozacc.mail.impl;

import java.util.Random;

import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.internet.MimeMessage;

/**
 * Message-IdإåޥǽMimeMessageΥ֥饹
 * 
 * @author Tomohiro Otsuka
 * @version $Id: OMLMimeMessage.java,v 1.1 2004/09/20 21:42:27 otsuka Exp $
 */
class OMLMimeMessage extends MimeMessage {

	private String messageId;

	private static Random random = new Random();

	/**
	 * 󥹥ȥ饯
	 * 
	 * @param session 
	 * @param messageId Message-IdإåΥɥᥤʬ˻Ѥʸ
	 */
	public OMLMimeMessage(Session session, String messageId) {
		super(session);

		String[] parts = messageId.split("@");
		if (parts.length == 1) {
			this.messageId = "@" + messageId;
		} else if (parts.length == 2) {
			if (parts[0].length() > 0 && !parts[0].startsWith(".")) {
				this.messageId = "." + messageId;
			} else {
				this.messageId = messageId;
			}
		}
	}

	/**
	 * Message-Idإå򤳤ǥåȤޤ
	 * <p>
	 * ͥڡ<br>
	 * <a href="http://java.sun.com/products/javamail/FAQ.html#msgid">http://java.sun.com/products/javamail/FAQ.html#msgid</a>
	 * 
	 * @see javax.mail.internet.MimeMessage#updateHeaders()
	 */
	protected void updateHeaders() throws MessagingException {
		super.updateHeaders();
		setHeader("Message-ID", generateRandomMessageId());
	}

	/**
	 * ॹ + 16 + messageIdץѥƥϢ뤷ʸ֤ޤ
	 * 
	 * @return ॹ + 16 + messageIdץѥƥϢ뤷ʸ
	 */
	protected String generateRandomMessageId() {
		StringBuffer buf = new StringBuffer();
		buf.append(System.currentTimeMillis()).append(".");
		for (int i = 0; i < 16; i++) {
			long num = Math.abs(random.nextInt(10));
			buf.append(num);
		}
		buf.append(messageId);
		return buf.toString();
	}

}

==> ozacc-mail-1.1.2-src.zip: ozacc-mail-1.1.2/src/java/com/ozacc/mail/impl/OMLMimeMessage.java <==
package com.ozacc.mail.impl;

import java.util.Random;

import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.internet.MimeMessage;

/**
 * Message-IdإåޥǽMimeMessageΥ֥饹
 * 
 * @since 1.1
 * 
 * @author Tomohiro Otsuka
 * @version $Id: OMLMimeMessage.java,v 1.3 2004/09/25 02:17:41 otsuka Exp $
 */
class OMLMimeMessage extends MimeMessage {

	private String messageId;

	private static Random random = new Random();

	/**
	 * 󥹥ȥ饯
	 * 
	 * @param session 
	 * @param messageId Message-IdإåΥɥᥤʬ˻Ѥʸ
	 */
	OMLMimeMessage(Session session, String messageId) {
		super(session);

		String[] parts = messageId.split("@");
		if (parts.length == 1) {
			this.messageId = "@" + messageId;
		} else if (parts.length == 2) {
			if (parts[0].length() > 0 && !parts[0].startsWith(".")) {
				this.messageId = "." + messageId;
			} else {
				this.messageId = messageId;
			}
		}
	}

	/**
	 * Message-Idإå򤳤ǥåȤޤ
	 * <p>
	 * ͥڡ<br>
	 * <a href="http://java.sun.com/products/javamail/FAQ.html#msgid">http://java.sun.com/products/javamail/FAQ.html#msgid</a>
	 * 
	 * @see javax.mail.internet.MimeMessage#updateHeaders()
	 */
	protected void updateHeaders() throws MessagingException {
		super.updateHeaders();
		setHeader("Message-ID", generateRandomMessageId());
	}

	/**
	 * ॹ + 16 + messageIdץѥƥϢ뤷ʸ֤ޤ
	 * 
	 * @return ॹ + 16 + messageIdץѥƥϢ뤷ʸ
	 */
	protected String generateRandomMessageId() {
		StringBuffer buf = new StringBuffer();
		buf.append(System.currentTimeMillis()).append(".");
		for (int i = 0; i < 16; i++) {
			long num = Math.abs(random.nextInt(10));
			buf.append(num);
		}
		buf.append(messageId);
		return buf.toString();
	}

}
